@@ -1,6 +1,6 @@
 ;; htmlize.el -- HTML-ize font-lock buffers
 
-;; Copyright (C) 1997,1998,1999 Hrvoje Niksic
+;; Copyright (C) 1997,1998,1999,2000 Hrvoje Niksic
 
 ;; Author: Hrvoje Niksic <hniksic@xemacs.org>
 ;; Keywords: hypermedia, extensions
@@ -24,7 +24,7 @@
 
 ;; This package analyses the text properties of the buffer and
 ;; converts them, along with the text, to HTML.  Mail to
-;; <hniksic@srce.hr> to discuss features and additions.  All
+;; <hniksic@xemacs.org> to discuss features and additions.  All
 ;; suggestions are more than welcome.
 
 ;; To use, just switch to a buffer you want HTML-ized, and type `M-x
@@ -52,7 +52,11 @@
 
 ;; The latest version should be available at:
 ;;
-;;        <URL:http://jagor.srce.hr/~hniksic/htmlize.el>
+;;        <URL:http://mraz.iskon.hr/~hniksic/htmlize.el>
+;;
+;; You can find the sample htmlize output (run on `htmlize.el') at:
+;;
+;;        <URL:http://mraz.iskon.hr/~hniksic/htmlize.html>
 ;;
 
 ;; Thanks go to:
@@ -71,7 +75,8 @@
 ;;   * Thomas Vogels <tov@ece.cmu.edu> and Juanma Barranquero
 ;;     <barranquero@laley-actualidad.es> for contributing fixes.
 ;;
-;;   * A bunch of other people for sending reports.
+;;   * A bunch of other people for sending reports and useful
+;;     comments.
 ;;
 
 ;; TODO: Should attempt to merge faces (utilize CSS for this?).
@@ -93,7 +98,7 @@
   (defvar font-lock-auto-fontify)
   (defvar global-font-lock-mode))
 
-(defconst htmlize-version "0.49")
+(defconst htmlize-version "0.50")
 
 ;; Incantations to make custom stuff work without customize, e.g. on
 ;; XEmacs 19.14 or GNU Emacs 19.34.
@@ -172,6 +177,116 @@ This is run by the `htmlize-file'.")
 
 ;;; Protection of HTML strings.
 
+;; This is only a stub.  Implementing this to be correct under all
+;; variants of Mule and Mule-disabled Emacs is extremely hard.  Leave
+;; it commented for now.
+
+;(defvar htmlize-protected-chars
+;  '((?& amp)
+;    (?< lt)
+;    (?> gt)
+;    (?\" quot))
+;  "Characters ordinarily protected by HTML.")
+
+;(defvar htmlize-latin1-entities
+;  '((160 nbsp)
+;    (161 iexcl)
+;    (162 cent)
+;    (163 pound)
+;    (164 curren)
+;    (165 yen)
+;    (166 brvbar)
+;    (167 sect)
+;    (168 uml)
+;    (169 copy)
+;    (170 ordf)
+;    (171 laquo)
+;    (172 not)
+;    (173 shy)
+;    (174 reg)
+;    (175 macr)
+;    (176 deg)
+;    (177 plusmn)
+;    (178 sup2)
+;    (179 sup3)
+;    (180 acute)
+;    (181 micro)
+;    (182 para)
+;    (183 middot)
+;    (184 cedil)
+;    (185 sup1)
+;    (186 ordm)
+;    (187 raquo)
+;    (188 frac14)
+;    (189 frac12)
+;    (190 frac34)
+;    (191 iquest)
+;    (192 Agrave)
+;    (193 Aacute)
+;    (194 Acirc)
+;    (195 Atilde)
+;    (196 Auml)
+;    (197 Aring)
+;    (198 AElig)
+;    (199 Ccedil)
+;    (200 Egrave)
+;    (201 Eacute)
+;    (202 Ecirc)
+;    (203 Euml)
+;    (204 Igrave)
+;    (205 Iacute)
+;    (206 Icirc)
+;    (207 Iuml)
+;    (208 ETH)
+;    (209 Ntilde)
+;    (210 Ograve)
+;    (211 Oacute)
+;    (212 Ocirc)
+;    (213 Otilde)
+;    (214 Ouml)
+;    (215 times)
+;    (216 Oslash)
+;    (217 Ugrave)
+;    (218 Uacute)
+;    (219 Ucirc)
+;    (220 Uuml)
+;    (221 Yacute)
+;    (222 THORN)
+;    (223 szlig)
+;    (224 agrave)
+;    (225 aacute)
+;    (226 acirc)
+;    (227 atilde)
+;    (228 auml)
+;    (229 aring)
+;    (230 aelig)
+;    (231 ccedil)
+;    (232 egrave)
+;    (233 eacute)
+;    (234 ecirc)
+;    (235 euml)
+;    (236 igrave)
+;    (237 iacute)
+;    (238 icirc)
+;    (239 iuml)
+;    (240 eth)
+;    (241 ntilde)
+;    (242 ograve)
+;    (243 oacute)
+;    (244 ocirc)
+;    (245 otilde)
+;    (246 ouml)
+;    (247 divide)
+;    (248 oslash)
+;    (249 ugrave)
+;    (250 uacute)
+;    (251 ucirc)
+;    (252 uuml)
+;    (253 yacute)
+;    (254 thorn)
+;    (255 yuml))
+;  "Mapping between Latin 1 characters and their corresponding HTML entities.")
+
 (defvar htmlize-character-table
   (let ((table (make-vector 256 ?\0)))
     (dotimes (i 256)
@@ -651,7 +766,11 @@ in the system directories."
   "HTML-ize FILE, and save the result.
 If TARGET-DIRECTORY is non-nil, the resulting HTML file will be saved
 to that directory, instead of to the FILE's directory."
-  (interactive "fHTML-ize file: ")
+  (interactive (list (read-file-name
+		      "HTML-ize file: "
+		      nil nil nil (and (buffer-file-name)
+				       (file-name-nondirectory
+					(buffer-file-name))))))
   (let* ((was-visited (get-file-buffer file))
 	 ;; Set these to nil to prevent double fontification; we'll
 	 ;; fontify manually below.
